@@ -41,7 +41,11 @@ class ParseOptions(object):
                  use_sat=False,
                  max_parse_time=-1,
                  disjunct_cost=2.7,
-                 repeatable_rand=True,):
+                 repeatable_rand=True,
+                 test='',
+                 debug='',
+                 dialect='',
+                 ):
 
         self._obj = clg.parse_options_create()
         self.verbosity = verbosity
@@ -57,6 +61,9 @@ class ParseOptions(object):
         self.max_parse_time = max_parse_time
         self.disjunct_cost = disjunct_cost
         self.repeatable_rand = repeatable_rand
+        self.test = test
+        self.debug = debug
+        self.dialect = dialect
 
     # Allow only the attribute names listed below.
     def __setattr__(self, name, value):
@@ -70,6 +77,36 @@ class ParseOptions(object):
             clg.parse_options_delete(self._obj)
             del self._obj
 
+    @property
+    def test(self):
+        return clg.parse_options_get_test(self._obj)
+
+    @test.setter
+    def test(self, value):
+        if not isinstance(value, str):
+            raise TypeError("test must be set to a string")
+        return clg.parse_options_set_test(self._obj, value)
+
+    @property
+    def debug(self):
+        return clg.parse_options_get_debug(self._obj)
+
+    @debug.setter
+    def debug(self, value):
+        if not isinstance(value, str):
+            raise TypeError("dialect must be set to a string")
+        return clg.parse_options_set_debug(self._obj, value)
+
+    @property
+    def dialect(self):
+        return clg.parse_options_get_dialect(self._obj)
+
+    @debug.setter
+    def dialect(self, value):
+        if not isinstance(value, str):
+            raise TypeError("dialect must be set to a string")
+        return clg.parse_options_set_dialect(self._obj, value)
+
     @property
     def verbosity(self):
         """
@@ -81,7 +118,7 @@ class ParseOptions(object):
     @verbosity.setter
     def verbosity(self, value):
         if not isinstance(value, int):
-            raise TypeError("Verbosity must be set to an integer")
+            raise TypeError("verbosity must be set to an integer")
         if value not in range(0,120):
             raise ValueError("Verbosity levels can be any integer between 0 and 120 inclusive")
         clg.parse_options_set_verbosity(self._obj, value)
@@ -100,9 +137,9 @@ class ParseOptions(object):
     @linkage_limit.setter
     def linkage_limit(self, value):
         if not isinstance(value, int):
-            raise TypeError("Linkage Limit must be set to an integer")
+            raise TypeError("linkage_limit must be set to an integer")
         if value < 0:
-            raise ValueError("Linkage Limit must be positive")
+            raise ValueError("linkage_limit must be positive")
         clg.parse_options_set_linkage_limit(self._obj, value)
 
     @property
@@ -117,7 +154,7 @@ class ParseOptions(object):
     @disjunct_cost.setter
     def disjunct_cost(self, value):
         if not isinstance(value, float):
-            raise TypeError("Distjunct cost must be set to a float")
+            raise TypeError("disjunct_cost must be set to a float")
         clg.parse_options_set_disjunct_cost(self._obj, value)
 
     @property
@@ -380,7 +417,7 @@ class Link(object):
 
     def __eq__(self, other):
         return self.left_word == other.left_word and self.left_label == other.left_label and \
-               self.right_word == other.right_word and self.right_label == other.right_label
+            self.right_word == other.right_word and self.right_label == other.right_label
 
     def __str__(self):
         if self.left_label == self.right_label:
@@ -420,7 +457,6 @@ class Linkage(object):
 
     __bool__ = __nonzero__      # Account python3
 
-
     def num_of_words(self):
         return clg.linkage_get_num_words(self._obj)
 
@@ -462,9 +498,6 @@ class Linkage(object):
     def postscript(self, display_walls=True, print_ps_header=False):
         return clg.linkage_print_postscript(self._obj, display_walls, print_ps_header)
 
-    def senses(self):
-        return clg.linkage_print_senses(self._obj)
-
     def constituent_tree(self, mode=1):
         return clg.linkage_print_constituent_tree(self._obj, mode)
 
@@ -484,6 +517,7 @@ class Linkage(object):
 class LG_TimerExhausted(LG_Error):
     pass
 
+
 class Sentence(object):
     """
     sent = Sentence("This is a test.", Dictionary(), ParseOptions())
